pub struct LineBuffer { /* private fields */ }Expand description
A line buffer manages a (typically fixed) buffer for holding lines.
Callers should create line buffers sparingly and reuse them when possible. Line buffers cannot be used directly, but instead must be used via the LineBufferReader.